@@ -77,7 +77,7 @@ const bool MyMoneyStatementReader::startImport(const MyMoneyStatement& s)
 
   m_account.setName(s.m_strAccountName);
   m_account.setNumber(s.m_strAccountNumber);
-  m_account.setValue("lastStatementBalance", QString::number(s.m_moneyClosingBalance));
+  m_account.setValue("lastStatementBalance", s.m_closingBalance.toString());
 
   if ( s.m_dateEnd.isValid() )
     m_account.setValue("lastStatementDate", s.m_dateEnd.toString("yyyy-MM-dd"));
@@ -108,7 +108,7 @@ const bool MyMoneyStatementReader::startImport(const MyMoneyStatement& s)
     m_userAbort = ! selectOrCreateAccount(Select, m_account);
 
   signalProgress(0, s.m_listTransactions.count(), "Importing Statement ...");
-    
+
   //
   // Process the transactions
   //
@@ -172,10 +172,13 @@ void MyMoneyStatementReader::processTransactionEntry(const MyMoneyStatement::Tra
   MyMoneySplit s1;
 
   s1.setMemo(t_in.m_strMemo);
-  s1.setValue(t_in.m_moneyAmount);
-  s1.setShares(t_in.m_moneyAmount);
+  s1.setValue(t_in.m_amount - t_in.m_fees);
+  s1.setShares(s1.value());
   s1.setNumber(t_in.m_strNumber);
 
+  // set these values if a transfer split is needed at the very end.
+  MyMoneyMoney transfervalue;
+
   // If the user has chosent to import into an investment account, determine the correct account to use
   MyMoneyAccount thisaccount = m_account;
   if ( thisaccount.accountType() == MyMoneyAccount::Investment )
@@ -208,7 +211,7 @@ void MyMoneyStatementReader::processTransactionEntry(const MyMoneyStatement::Tra
         MyMoneyPrice price = file->price( currencyid, basecurrencyid, t_in.m_datePosted, true );
         if ( !price.isValid() )
         {
-          MyMoneyPrice newprice( currencyid, basecurrencyid, t_in.m_datePosted, t_in.m_moneyAmount / t_in.m_dShares, i18n("Statement Importer") );
+          MyMoneyPrice newprice( currencyid, basecurrencyid, t_in.m_datePosted, t_in.m_amount / t_in.m_shares, i18n("Statement Importer") );
           file->addPrice(newprice);
         }
       }
@@ -227,14 +230,14 @@ void MyMoneyStatementReader::processTransactionEntry(const MyMoneyStatement::Tra
 
     if (t_in.m_eAction==MyMoneyStatement::Transaction::eaReinvestDividend)
     {
-      s1.setShares(MyMoneyMoney(t_in.m_dShares,1000));
+      s1.setShares(t_in.m_shares);
       s1.setAction(MyMoneySplit::ActionReinvestDividend);
-      
+
       MyMoneySplit s2;
       s2.setMemo(t_in.m_strMemo);
       s2.setAccountId(findOrCreateIncomeAccount("_Dividend"));
-      s2.setShares(-t_in.m_moneyAmount);
-      s2.setValue(-t_in.m_moneyAmount);
+      s2.setShares(-t_in.m_amount);
+      s2.setValue(-t_in.m_amount);
       t.addSplit(s2);
     }
     if (t_in.m_eAction==MyMoneyStatement::Transaction::eaCashDividend)
@@ -249,8 +252,8 @@ void MyMoneyStatementReader::processTransactionEntry(const MyMoneyStatement::Tra
       // amount into the transaction.
 
       s1.setAccountId(findOrCreateIncomeAccount("_Dividend"));
-      s1.setShares(-t_in.m_moneyAmount);
-      s1.setValue(-t_in.m_moneyAmount);
+      s1.setShares(-t_in.m_amount);
+      s1.setValue(-t_in.m_amount);
 
       // Split 2 will be the zero-amount investment split that serves to
       // mark this transaction as a cash dividend and note which stock account
@@ -261,11 +264,15 @@ void MyMoneyStatementReader::processTransactionEntry(const MyMoneyStatement::Tra
       s2.setAction(MyMoneySplit::ActionDividend);
       s2.setAccountId(thisaccount.id());
       t.addSplit(s2);
+
+      transfervalue = -t_in.m_amount - t_in.m_fees;
     }
     else if (t_in.m_eAction==MyMoneyStatement::Transaction::eaBuy || t_in.m_eAction==MyMoneyStatement::Transaction::eaSell)
     {
-      s1.setShares(MyMoneyMoney(t_in.m_dShares,1000));
+      s1.setShares(t_in.m_shares);
       s1.setAction(MyMoneySplit::ActionBuyShares);
+
+      transfervalue = -t_in.m_amount;
     }
 
   }
@@ -341,7 +348,7 @@ void MyMoneyStatementReader::processTransactionEntry(const MyMoneyStatement::Tra
       }
       delete e;
     }
-    
+
     //
     // Fill in other side of the transaction (category/etc) based on payee
     //
@@ -364,7 +371,7 @@ void MyMoneyStatementReader::processTransactionEntry(const MyMoneyStatement::Tra
     {
       // Default to using the most recent transaction as the reference
       MyMoneyTransaction t_old = list.last();
-      
+
       // if there is more than one matching transaction, try to be a little
       // smart about which one we take.  for now, we'll see if there's one
       // with the same VALUE as our imported transaction, and if so take that one.
@@ -378,11 +385,11 @@ void MyMoneyStatementReader::processTransactionEntry(const MyMoneyStatement::Tra
           {
             t_old = *it_trans;
             break;
-          }        
-          --it_trans;        
-        }      
+          }
+          --it_trans;
+        }
       }
-    
+
       QValueList<MyMoneySplit>::ConstIterator it_split;
       for(it_split = t_old.splits().begin(); it_split != t_old.splits().end(); ++it_split)
       {
@@ -393,7 +400,7 @@ void MyMoneyStatementReader::processTransactionEntry(const MyMoneyStatement::Tra
           MyMoneySplit s(*it_split);
           s.setReconcileFlag(MyMoneySplit::NotReconciled);
           s.setId(QCString());
-    
+
           if ( t_old.splits().count() == 2 )
           {
             s.setShares(-s1.shares());
@@ -403,11 +410,42 @@ void MyMoneyStatementReader::processTransactionEntry(const MyMoneyStatement::Tra
         }
       }
     }
-    
+
   }
 
   t.addSplit(s1);
 
+  // The fees has to be added AFTER the interest, because
+  // KLedgerViewInvestments::preloadInvestmentSplits expects the splits to be
+  // ordered this way.
+  if ( !t_in.m_fees.isZero() )
+  {
+    MyMoneySplit s;
+    s.setMemo(i18n("(Fees) ") + t_in.m_strMemo);
+    s.setValue(t_in.m_fees);
+    s.setShares(t_in.m_fees);
+    s.setAccountId(findOrCreateExpenseAccount("_Fees"));
+    t.addSplit(s);
+  }
+
+  // Add the 'account' split if it's needed
+  if ( ! transfervalue.isZero() )
+  {
+    QCString brokerageactid = m_account.value("kmm-brokerage-account").utf8();
+
+    if ( !brokerageactid.isEmpty() )
+    {
+      // FIXME This may not deal with foreign currencies properly
+      MyMoneySplit s;
+      s.setMemo(t_in.m_strMemo);
+      s.setValue(transfervalue);
+      s.setShares(transfervalue);
+      s.setAccountId(brokerageactid);
+      t.addSplit(s);
+    }
+  }
+
+
   // Add the transaction
   try {
     // check for duplicates ONLY by Bank ID in this account.
@@ -430,11 +468,11 @@ void MyMoneyStatementReader::processTransactionEntry(const MyMoneyStatement::Tra
   } catch (MyMoneyException *e) {
     QString message(i18n("Problem adding imported transaction: "));
     message += e->what();
-    
+
     int result = KMessageBox::warningContinueCancel(0, message);
     if ( result == KMessageBox::Cancel )
         throw new MYMONEYEXCEPTION("USERABORT");
-    
+
     delete e;
   }
 }
@@ -530,7 +568,7 @@ bool MyMoneyStatementReader::selectOrCreateAccount(const SelectCreateMode /*mode
         //throw new MYMONEYEXCEPTION("USERABORT");
         done = true;
       else
-        KMessageBox::error(0, i18n("You must select an account, create a new one, or press the <b>Abort</b> button."));
+        KMessageBox::error(0, QString("<qt>%1</qt>").arg(i18n("You must select an account, create a new one, or press the <b>Abort</b> button.")));
     }
   }
   return result;
@@ -550,7 +588,7 @@ void MyMoneyStatementReader::signalProgress(int current, int total, const QStrin
 const QCString MyMoneyStatementReader::findOrCreateIncomeAccount(const QString& searchname)
 {
   QCString result;
-  
+
   MyMoneyFile *file = MyMoneyFile::instance();
 
   // First, try to find this account as an income account
@@ -564,7 +602,7 @@ const QCString MyMoneyStatementReader::findOrCreateIncomeAccount(const QString&
     {
       result = *it_accid;
       break;
-    }  
+    }
     ++it_accid;
   }
 
@@ -582,4 +620,39 @@ const QCString MyMoneyStatementReader::findOrCreateIncomeAccount(const QString&
   return result;
 }
 
+const QCString MyMoneyStatementReader::findOrCreateExpenseAccount(const QString& searchname)
+{
+  QCString result;
+
+  MyMoneyFile *file = MyMoneyFile::instance();
+
+  // First, try to find this account as an income account
+  MyMoneyAccount acc = file->expense();
+  QCStringList list = acc.accountList();
+  QCStringList::ConstIterator it_accid = list.begin();
+  while ( it_accid != list.end() )
+  {
+    acc = file->account(*it_accid);
+    if ( acc.name() == searchname )
+    {
+      result = *it_accid;
+      break;
+    }
+    ++it_accid;
+  }
+
+  // If we did not find the account, now we must create one.
+  if ( result.isEmpty() )
+  {
+    MyMoneyAccount acc;
+    acc.setName( searchname );
+    acc.setAccountType( MyMoneyAccount::Expense );
+    MyMoneyAccount expense = file->expense();
+    file->addAccount( acc, expense );
+    result = acc.id();
+  }
+
+  return result;
+}
+
 #include "mymoneystatementreader.moc"
