@@ -178,6 +178,7 @@ KEditScheduleDialog::KEditScheduleDialog(const QCString& action, const MyMoneySc
     this, SLOT(slotEstimateChanged()));
   connect(m_category, SIGNAL(textChanged(const QString&)),
     this, SLOT(slotCategoryChanged(const QString&)));
+  connect(m_category, SIGNAL(categoryChanged(const QCString&)), this, SLOT(slotCategoryChanged(const QCString& )));
   connect(m_qcheckboxAuto, SIGNAL(clicked()),
     this, SLOT(slotAutoEnterChanged()));
   connect(m_qlineeditMemo, SIGNAL(textChanged(const QString&)),
@@ -445,13 +446,13 @@ void KEditScheduleDialog::okClicked()
     m_scheduleName->setFocus();
     return;
   }
-  
+
   if(m_accountCombo->isEnabled() && m_accountCombo->selectedAccounts().count() == 0) {
     KMessageBox::information(this, i18n("Please fill in the From account field."));
     m_accountCombo->setFocus();
     return;
   }
-  
+
   if(m_kcomboTo->isEnabled() && m_kcomboTo->selectedAccounts().count() == 0) {
     KMessageBox::information(this, i18n("Please fill in the To account field."));
     m_kcomboTo->setFocus();
@@ -1068,6 +1069,22 @@ void KEditScheduleDialog::slotEstimateChanged()
   m_schedule.setFixed(!m_qcheckboxEstimate->isChecked());
 }
 
+void KEditScheduleDialog::slotCategoryChanged(const QCString& id)
+{
+  if(!id.isEmpty()) {
+    int count = m_transaction.splitCount();
+    if (count == 0)
+    {
+      createSplits();
+    }
+
+    // Dont worry about transfers
+    MyMoneySplit s = m_transaction.splits()[1];
+    s.setAccountId(id);
+    m_transaction.modifySplit(s);
+  }
+}
+
 void KEditScheduleDialog::slotCategoryChanged(const QString& text)
 {
   if (text != i18n("Split Transaction"))
@@ -1300,7 +1317,7 @@ QCString KEditScheduleDialog::theAccountId()
       m_actionType == MyMoneySplit::ActionAmortization ||
       m_actionType == MyMoneySplit::ActionWithdrawal ||
       m_actionType == MyMoneySplit::ActionCheck ||
-      m_actionType == MyMoneySplit::ActionATM)      
+      m_actionType == MyMoneySplit::ActionATM)
   {
     return m_fromAccountId;
   }
