@@ -51,9 +51,6 @@
 KBackupDlg::KBackupDlg( QWidget* parent,  const char* name/*, bool modal*/)
   : kbackupdlgdecl( parent,  name , true)
 {
-  QString filename = KGlobal::dirs()->findResource("appdata", "pics/dlg_backup.png");
-  m_qpixmaplabel->setPixmap(QPixmap(filename));
-
   readConfig();
 
   // add icons to buttons
@@ -109,3 +106,5 @@ void KBackupDlg::writeConfig(void)
   config->writeEntry("KBackupDlg_BackupMountPoint", txtMountPoint->text());
   config->sync();
 }
+
+#include "kbackupdlg.moc"
