@@ -664,134 +664,140 @@ void KEnterScheduleDialog::commitTransaction()
       // Splits not referencing any account will be removed.
       // Price information for other currencies will be collected
 
-      QMap<QCString, MyMoneyMoney> priceInfo;
-      for(it = list.begin(); it != list.end(); ++it) {
-        if((*it).accountId().isEmpty()) {
-          m_transaction.removeSplit(*it);
-          continue;
-        }
-        MyMoneyAccount acc = file->account((*it).accountId());
-        MyMoneySecurity currency(file->currency(m_schedule.account().currencyId()));
-        int fract = currency.smallestAccountFraction();
-        if(acc.accountType() == MyMoneyAccount::Cash)
-          fract = currency.smallestCashFraction();
+      // If the value of the account's split is 0, then we interpret this
+      // as "the user wants to skip this payment". Fixes bug reported on
+      // http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=412264
+      if(list.count() > 0 && !list[0].value().isZero()) {
+        QMap<QCString, MyMoneyMoney> priceInfo;
+        for(it = list.begin(); it != list.end(); ++it) {
+          if((*it).accountId().isEmpty()) {
+            m_transaction.removeSplit(*it);
+            continue;
+          }
+          MyMoneyAccount acc = file->account((*it).accountId());
+          MyMoneySecurity currency(file->currency(m_schedule.account().currencyId()));
+          int fract = currency.smallestAccountFraction();
+          if(acc.accountType() == MyMoneyAccount::Cash)
+            fract = currency.smallestCashFraction();
 
-        MyMoneyAccount::accountTypeE accType = file->accountGroup(acc.accountType());
-        switch(accType) {
-          case MyMoneyAccount::Asset:
-          case MyMoneyAccount::Liability:
-            break;
+          MyMoneyAccount::accountTypeE accType = file->accountGroup(acc.accountType());
+          switch(accType) {
+            case MyMoneyAccount::Asset:
+            case MyMoneyAccount::Liability:
+              break;
 
-          default:
-            (*it).setPayeeId(QCString());
-            m_transaction.modifySplit(*it);
-            break;
-        }
+            default:
+              (*it).setPayeeId(QCString());
+              m_transaction.modifySplit(*it);
+              break;
+          }
 
-        if(m_transaction.commodity() != acc.currencyId()) {
-          // different currencies, try to find recent price info
-          QMap<QCString, MyMoneyMoney>::Iterator it_p;
-          QCString key = m_transaction.commodity() + "-" + acc.currencyId();
-          it_p = priceInfo.find(key);
+          if(m_transaction.commodity() != acc.currencyId()) {
+            // different currencies, try to find recent price info
+            QMap<QCString, MyMoneyMoney>::Iterator it_p;
+            QCString key = m_transaction.commodity() + "-" + acc.currencyId();
+            it_p = priceInfo.find(key);
 
-          // if it's not found, then collect it from the user first
-          MyMoneyMoney price;
-          if(it_p == priceInfo.end()) {
-            MyMoneySecurity fromCurrency, toCurrency;
-            MyMoneyMoney fromValue, toValue;
-            if(m_transaction.commodity() != m_schedule.account().currencyId()) {
-              toCurrency = file->currency(m_transaction.commodity());
-              fromCurrency = file->currency(acc.currencyId());
-              toValue = (*it).value();
-              fromValue = (*it).shares();
+            // if it's not found, then collect it from the user first
+            MyMoneyMoney price(1,1);
+
+            if(it_p == priceInfo.end()) {
+              MyMoneySecurity fromCurrency, toCurrency;
+              MyMoneyMoney fromValue, toValue;
+              if(m_transaction.commodity() != m_schedule.account().currencyId()) {
+                toCurrency = file->currency(m_transaction.commodity());
+                fromCurrency = file->currency(acc.currencyId());
+                toValue = (*it).value();
+                fromValue = (*it).shares();
+              } else {
+                fromCurrency = file->currency(m_transaction.commodity());
+                toCurrency = file->currency(acc.currencyId());
+                fromValue = (*it).value();
+                toValue = (*it).shares();
+              }
+
+              KCurrencyCalculator calc(fromCurrency,
+                                      toCurrency,
+                                      fromValue,
+                                      toValue,
+                                      m_transaction.postDate(),
+                                      fract,
+                                      this, "currencyCalculator");
+              if(calc.exec() == QDialog::Rejected) {
+                return;
+              }
+              price = calc.price();
+              priceInfo[key] = price;
             } else {
-              fromCurrency = file->currency(m_transaction.commodity());
-              toCurrency = file->currency(acc.currencyId());
-              fromValue = (*it).value();
-              toValue = (*it).shares();
+              price = (*it_p);
             }
 
-            KCurrencyCalculator calc(fromCurrency,
-                                    toCurrency,
-                                    fromValue,
-                                    toValue,
-                                    m_transaction.postDate(),
-                                    fract,
-                                    this, "currencyCalculator");
-            if(calc.exec() == QDialog::Rejected) {
-              return;
+            // update shares if the transaction commodity is the currency
+            // of the current selected account
+            if(m_transaction.commodity() == m_schedule.account().currencyId()) {
+              (*it).setShares(((*it).value() * price).convert(fract));
             }
-            price = calc.price();
-            priceInfo[key] = price;
-          } else {
-            price = (*it_p);
-          }
 
-          // update shares if the transaction commodity is the currency
-          // of the current selected account
-          if(m_transaction.commodity() == m_schedule.account().currencyId()) {
-            (*it).setShares(((*it).value() * price).convert(fract));
-          }
-
-          // now update the split
-          m_transaction.modifySplit(*it);
-        } else {
-          if((*it).shares() != (*it).value()) {
-            (*it).setShares((*it).value());
+            // now update the split
             m_transaction.modifySplit(*it);
+          } else {
+            if((*it).shares() != (*it).value()) {
+              (*it).setShares((*it).value());
+              m_transaction.modifySplit(*it);
+            }
           }
         }
-      }
 
 #if 0
-      // FIXME: This should be run through, but currently we don't have
-      // access to the transactionType() routine. So we keep the source here
-      // and let things go.
-      if(transactionType(m_transaction) == Transfer && !m_split.payeeId().isEmpty()) {
-        for(it = list.begin(); it != list.end(); ++it) {
-          if((*it).id() == m_split.id())
-            continue;
-
-          if((*it).payeeId().isEmpty()) {
-            (*it).setPayeeId(m_split.payeeId());
-            m_transaction.modifySplit(*it);
-          }
-        }
-      }
-
-      // check if this is a transfer to/from loan account and
-      // mark it as amortization in this case
-      if(m_transaction.splitCount() == 2) {
-        bool isAmortization = false;
-        for(it = list.begin(); !isAmortization && it != list.end(); ++it) {
-          if((*it).action() == MyMoneySplit::ActionTransfer) {
-            MyMoneyAccount acc = file->account((*it).accountId());
-            if(acc.accountType() == MyMoneyAccount::Loan
-            || acc.accountType() == MyMoneyAccount::AssetLoan)
-              isAmortization = true;
-          }
-        }
-
-        if(isAmortization) {
+        // FIXME: This should be run through, but currently we don't have
+        // access to the transactionType() routine. So we keep the source here
+        // and let things go.
+        if(transactionType(m_transaction) == Transfer && !m_split.payeeId().isEmpty()) {
           for(it = list.begin(); it != list.end(); ++it) {
-            (*it).setAction(MyMoneySplit::ActionAmortization);
-            m_transaction.modifySplit(*it);
+            if((*it).id() == m_split.id())
+              continue;
+
+            if((*it).payeeId().isEmpty()) {
+              (*it).setPayeeId(m_split.payeeId());
+              m_transaction.modifySplit(*it);
+            }
+          }
+        }
+
+        // check if this is a transfer to/from loan account and
+        // mark it as amortization in this case
+        if(m_transaction.splitCount() == 2) {
+          bool isAmortization = false;
+          for(it = list.begin(); !isAmortization && it != list.end(); ++it) {
+            if((*it).action() == MyMoneySplit::ActionTransfer) {
+              MyMoneyAccount acc = file->account((*it).accountId());
+              if(acc.accountType() == MyMoneyAccount::Loan
+              || acc.accountType() == MyMoneyAccount::AssetLoan)
+                isAmortization = true;
+            }
+          }
+
+          if(isAmortization) {
+            for(it = list.begin(); it != list.end(); ++it) {
+              (*it).setAction(MyMoneySplit::ActionAmortization);
+              m_transaction.modifySplit(*it);
+            }
           }
         }
-      }
 #endif
 
-      // If we are writing a check, we adjust the split's
-      // number to the highest number used in this account plus one
-      if(m_schedule.paymentType() == MyMoneySchedule::STYPE_WRITECHEQUE) {
-        MyMoneySplit s = m_transaction.splitByAccount(m_schedule.account().id(), true);
-        s.setAction(MyMoneySplit::ActionCheck);
-        unsigned64 no = MyMoneyFile::instance()->highestCheckNo(s.accountId()).toULongLong();
-        s.setNumber(QString::number(no+1));
-        m_transaction.modifySplit(s);
-      }
+        // If we are writing a check, we adjust the split's
+        // number to the highest number used in this account plus one
+        if(m_schedule.paymentType() == MyMoneySchedule::STYPE_WRITECHEQUE) {
+          MyMoneySplit s = m_transaction.splitByAccount(m_schedule.account().id(), true);
+          s.setAction(MyMoneySplit::ActionCheck);
+          unsigned64 no = MyMoneyFile::instance()->highestCheckNo(s.accountId()).toULongLong();
+          s.setNumber(QString::number(no+1));
+          m_transaction.modifySplit(s);
+        }
 
-      MyMoneyFile::instance()->addTransaction(m_transaction);
+        MyMoneyFile::instance()->addTransaction(m_transaction);
+      }
       MyMoneyFile::instance()->modifySchedule(m_schedule);
     } catch(MyMoneyException *e) {
       KMessageBox::detailedSorry(0, i18n("Unable to add transaction/modify schedule"),
