@@ -49,9 +49,10 @@
 #include "../mymoney/mymoneyfile.h"
 #include "../mymoney/storage/imymoneystorage.h"
 
-KFindTransactionDlg::KFindTransactionDlg(QWidget *parent, const char *name)
+KFindTransactionDlg::KFindTransactionDlg(QWidget *parent, const char *name, bool forceSearchEnabled)
  : KFindTransactionDlgDecl(parent, name, false),
-  m_transactionPtr(0)
+  m_transactionPtr(0),
+  m_forceSearchEnabled(forceSearchEnabled)
 {
   // hide the transaction register and make sure the dialog is
   // displayed as small as can be. We make sure that the larger
@@ -255,6 +256,10 @@ void KFindTransactionDlg::slotUpdateSelections(void)
     txt += i18n("Details");
   }
 
+  // disable the search button if no selection is made
+  if(!m_forceSearchEnabled)
+    m_searchButton->setDisabled(txt.isEmpty());
+
   if(txt.isEmpty()) {
     txt = i18n("(None)");
   }
@@ -574,9 +579,30 @@ void KFindTransactionDlg::setupFilter(void)
   }
 
   // Account tab
-  // TOM: Why was this commented out? (Ace)
   if(!m_accountsView->allAccountsSelected()) {
-    m_filter.addAccount(m_accountsView->selectedAccounts());
+    // retrieve a list of selected accounts
+    QCStringList list = m_accountsView->selectedAccounts();
+
+    // if we're not in expert mode, we need to make sure
+    // that all stock accounts for the selected investment
+    // account are also selected
+    if(!KMyMoneyUtils::isExpertMode()) {
+      QCStringList missing;
+      QCStringList::const_iterator it_a, it_b;
+      for(it_a = list.begin(); it_a != list.end(); ++it_a) {
+        MyMoneyAccount acc = MyMoneyFile::instance()->account(*it_a);
+        if(acc.accountType() == MyMoneyAccount::Investment) {
+          for(it_b = acc.accountList().begin(); it_b != acc.accountList().end(); ++it_b) {
+            if(!list.contains(*it_b)) {
+              missing.append(*it_b);
+            }
+          }
+        }
+      }
+      list += missing;
+    }
+
+    m_filter.addAccount(list);
   }
 
   // Date tab
