@@ -64,8 +64,7 @@
 #define TAB_GENERAL      0
 #define TAB_TAX          1
 
-KNewAccountDlg::KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bool categoryEditor, QWidget *parent,
-    const char *name, const char *title)
+KNewAccountDlg::KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bool categoryEditor, QWidget *parent, const char *name, const QString& title)
   : KNewAccountDlgDecl(parent,name,true),
     m_account(account),
     m_bSelectedParentAccount(false),
