@@ -70,9 +70,9 @@ public:
     *                       If @p true, rules for income/expense account apply.
     * @param parent Pointer to parent object (passed to QDialog). Default is 0.
     * @param name Name of the object (passed to QDialog). Default is 0.
-    * @param title Caption of the object (passed to QDialog). Default is 0.
+    * @param title Caption of the object (passed to QDialog). Default is empty string.
     */
-  KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bool categoryEditor, QWidget *parent=0, const char *name=0, const char *title=0);
+  KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bool categoryEditor, QWidget *parent=0, const char *name=0, const QString& title = QString::null);
   ~KNewAccountDlg();
 
   /**
