@@ -181,8 +181,20 @@ void KNewAccountWizard::next()
     if(currentPage() == brokerageAccountPage) {
       setAppropriate(accountDetailsPage, brokerageYesButton->isChecked());
     }
+
     KNewAccountWizardDecl::next();
 
+    if(currentPage() == accountNamePage) {
+      accountName->setFocus();
+
+    } else if(currentPage() == accountNumberPage) {
+      accountNumber->setFocus();
+
+    } else if(currentPage() == accountDetailsPage) {
+      KLineEdit* edit = openingBalance->lineedit();
+      if(edit->hasFocus() && !edit->text().isEmpty() && !edit->hasSelectedText())
+        edit->selectAll();
+    }
     // setup the availability of widgets on the selected page
     slotCheckPageFinished();
   }
