@@ -25,6 +25,7 @@
 #include <kcombobox.h>
 #include <kurlrequester.h>
 #include <klocale.h>
+#include <kapplication.h>
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -125,9 +126,7 @@ void KNewInvestmentWizard::init(void)
   kMyMoneyMoneyValidator* fractionValidator = new kMyMoneyMoneyValidator(1, 100000, 0, this);
   m_fraction->setValidator(fractionValidator);
 
-  // FIXME for now, we don't have online help
-  helpButton()->hide();
-
+  connect(helpButton(),SIGNAL(clicked()), this, SLOT(slotHelp(void)));
   connect(m_investmentName, SIGNAL(textChanged(const QString&)), this, SLOT(slotCheckPage(void)));
   connect(m_investmentSymbol, SIGNAL(textChanged(const QString&)), this, SLOT(slotCheckPage(void)));
   connect(m_fraction, SIGNAL(textChanged(const QString&)), this, SLOT(slotCheckPage(void)));
@@ -169,6 +168,11 @@ void KNewInvestmentWizard::slotCheckPage(void)
   }
 }
 
+void KNewInvestmentWizard::slotHelp(void)
+{
+  kapp->invokeHelp("details.investments.newinvestmentwizard");
+}
+
 void KNewInvestmentWizard::createObjects(const QCString& parentId)
 {
   MyMoneyFile* file = MyMoneyFile::instance();
