@@ -67,7 +67,7 @@
 
 KReportConfigurationFilterDlg::KReportConfigurationFilterDlg(
   MyMoneyReport report, QWidget *parent, const char *name)
- : KFindTransactionDlg(parent, name),
+ : KFindTransactionDlg(parent, name, true),
  m_tab2(0),
  m_tab3(0),
  m_initialState(report),
