@@ -20,6 +20,7 @@
 // QT Includes
 
 #include <qcheckbox.h>
+#include <qgroupbox.h>
 #include <qradiobutton.h>
 #include <qbuttongroup.h>
 #include <qcolor.h>
@@ -79,6 +80,9 @@ private:
   /** Start last page */
   QRadioButton *m_qradiobuttonStartLast;
 
+  /** Prefer system colors */
+  QCheckBox* m_systemColor;
+  QGroupBox* m_colorGroupBox;
   /** Color list */
   KColorButton *m_kcolorbuttonList;
   /** Color background */
@@ -220,6 +224,7 @@ private:
   bool m_bTempStartPage;
   bool m_bTempCheckSchedule;
   bool m_bTempUseSystemFont;
+  bool m_bTempUseSystemColor;
   bool m_bTempFocusChangeEnter;
   bool m_bTempAutoFillTransaction;
   int  m_iTempSchedulePreview;
@@ -247,6 +252,9 @@ private slots:
   /** Called when 'Copy Type to Nr field' is toggled */
   void slotTypeToNrToggled(bool state);
 
+  /** Called when 'Use system color' is toggled */
+  void slotSystemColorToggled(bool state);
+
   /** Called when 'Use system font' is toggled */
   void slotSystemFontToggled(bool state);
 
