@@ -42,6 +42,7 @@
 QColor KMyMoneyUtils::_backgroundColour;
 QColor KMyMoneyUtils::_listColour;
 QColor KMyMoneyUtils::_gridColour;
+QColor KMyMoneyUtils::_missingConversionColour;
 
 QFont  KMyMoneyUtils::_cellFont;
 QFont  KMyMoneyUtils::_headerFont;
@@ -562,54 +563,40 @@ void KMyMoneyUtils::newPayee(QWidget* parent, kMyMoneyPayee* payeeEdit, const QS
     payeeEdit->resetText();
 }
 
-const QColor KMyMoneyUtils::defaultBackgroundColour(void)
-{
-  return KGlobalSettings::baseColor();
-  // return QColor(255,255,204);
-}
-
-const QColor KMyMoneyUtils::defaultListColour(void)
-{
-  QColor color = KGlobalSettings::alternateBackgroundColor();
-  if(!color.isValid())
-    color = defaultBackgroundColour();
-  return color;
-  // return QColor(255,255,238);
-}
-
-const QColor KMyMoneyUtils::defaultGridColour(void)
-{
-  return QColor(154,154,154);
-}
-
 void KMyMoneyUtils::updateSettings(void)
 {
-  QColor c;
-  QFont  f;
   KConfig *config = KGlobal::config();
   config->setGroup("List Options");
 
-  c = defaultBackgroundColour();
-  _backgroundColour = config->readColorEntry("listBGColor", &c);
+  bool useSystemColor = config->readBoolEntry("useSystemColor", true);
+  bool useSystemFont = config->readBoolEntry("useSystemFont", true);
 
-  c = defaultListColour();
-  _listColour = config->readColorEntry("listColor", &c);
+  _backgroundColour = KGlobalSettings::baseColor();
+  if(!useSystemColor)
+    _backgroundColour = config->readColorEntry("listBGColor", &_backgroundColour);
 
-  c = defaultGridColour();
-  _gridColour = config->readColorEntry("listGridColor", &c);
+  _listColour = KGlobalSettings::alternateBackgroundColor();
+  if(!_listColour.isValid())
+    _listColour = KGlobalSettings::baseColor();
+  if(!useSystemColor)
+    _listColour = config->readColorEntry("listColor", &_listColour);
 
-  f = KGlobalSettings::generalFont();
-  if(config->readBoolEntry("useSystemFont", true) == false)
-    _cellFont = config->readFontEntry("listCellFont", &f);
-  else
-    _cellFont = f;
+  _gridColour = QColor(154,154,154); // grey is the application default
+  if(!useSystemColor)
+    _gridColour = config->readColorEntry("listGridColor", &_gridColour);
 
-  f = KGlobalSettings::generalFont();
-  f.setBold(true);
-  if(config->readBoolEntry("useSystemFont", true) == false)
-    _headerFont = config->readFontEntry("listHeaderFont", &f);
-  else
-    _headerFont = f;
+  _missingConversionColour = QColor(0, 0, 255); // blue is the application default
+  if(!useSystemColor)
+    _missingConversionColour = config->readColorEntry("listMissingConversionRate", &_missingConversionColour);
+
+  _cellFont = KGlobalSettings::generalFont();
+  if(!useSystemFont)
+    _cellFont = config->readFontEntry("listCellFont", &_cellFont);
+
+  _headerFont = KGlobalSettings::generalFont();
+  _headerFont.setBold(true);
+  if(!useSystemFont)
+    _headerFont = config->readFontEntry("listHeaderFont", &_headerFont);
 
   config->setGroup("General Options");
   _expertMode = config->readBoolEntry("ExpertMode", false);
