@@ -36,6 +36,7 @@
 #include "mymoneymoney.h"
 #include "mymoneyutils.h"
 #include "mymoneykeyvaluecontainer.h"
+#include <kmymoney/mymoneysecurity.h>
 #include <kmymoney/export.h>
 class MyMoneyTransaction;
 class MyMoneyInstitution;
@@ -456,6 +457,17 @@ public:
     */
   void setCurrencyId(const QCString& id);
 
+  /**
+    * returns the applicable smallest fraction for this account
+    * for the given security based on the account type.
+    *
+    * @param sec const reference to currency (security)
+    *
+    * @retval sec.smallestCashFraction() for account type Cash
+    * @retval sec.smallestAccountFraction() for all other account types
+    */
+  int fraction(const MyMoneySecurity& sec) const;
+
 private:
   /**
     * This member variable identifies the type of account
