@@ -78,6 +78,12 @@ class MyMoneyFileTest : public CppUnit::TestFixture  {
 	CPPUNIT_TEST(testAccount2Category);
 	CPPUNIT_TEST(testCategory2Account);
 	CPPUNIT_TEST(testAttachedStorage);
+	CPPUNIT_TEST(testHasAccount);
+	CPPUNIT_TEST(testAddEquityAccount);
+	CPPUNIT_TEST(testReparentEquity);
+	CPPUNIT_TEST(testBaseCurrency);
+	CPPUNIT_TEST(testOpeningBalanceNoBase);
+	CPPUNIT_TEST(testOpeningBalance);
 #if 0
 	CPPUNIT_TEST(testMoveSplits);
 #endif
@@ -124,6 +130,13 @@ public:
 	void testAccount2Category();
 	void testCategory2Account();
 	void testAttachedStorage();
+	void testHasAccount();
+	void testAddEquityAccount();
+	void testReparentEquity();
+	void testReparentEquity(QValueList<MyMoneyAccount::accountTypeE>& list, MyMoneyAccount& parent);
+	void testBaseCurrency();
+	void testOpeningBalanceNoBase();
+	void testOpeningBalance();
 
 private:
 	void testRemoveStdAccount(const MyMoneyAccount& acc);
