@@ -17,6 +17,10 @@
 #ifndef MYMONEYINSTITUTION_H
 #define MYMONEYINSTITUTION_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -28,7 +32,8 @@
 // Project Includes
 
 #include "mymoneyutils.h"
-
+#include "mymoneykeyvaluecontainer.h"
+#include <kmymoney/export.h>
 
 class MyMoneyFile;
 class MyMoneyMoney;
@@ -38,7 +43,7 @@ class MyMoneyMoney;
   *
   * @author Thomas Baumgart
   */
-class MyMoneyInstitution {
+class KMYMONEY_EXPORT MyMoneyInstitution {
 public:
   /**
     * This is the constructor for a new empty institution description
@@ -65,11 +70,10 @@ public:
 
   /**
     * This is the constructor for a new institution known to the current file
-    * @param file pointer to current MyMoneyFile object
+    *
     * @param ID id assigned to the institution
     * @param right institution definition
     */
-  //MyMoneyInstitution(MyMoneyFile *file, const QString ID, const MyMoneyInstitution& right);
   MyMoneyInstitution(const QCString ID, const MyMoneyInstitution& right);
 
   const QString& manager(void) const { return m_manager; }
@@ -91,6 +95,22 @@ public:
   void setSortcode(QString code) { m_sortcode = code; }
   void setId(QString id)          { m_id = id; }
 
+  /**
+    * This method sets the kvp's for OFX Direct Connect sessions to this
+    * institution.
+    *
+    * @param values The container of kvp's needed when connecting to this institution
+    */
+  void setOfxConnectionSettings(const MyMoneyKeyValueContainer& values) { m_ofxConnectionSettings = values; }
+  
+  /**
+    * This method retrieves the kvp's for OFX Direct Connect sessions to this
+    * institution.
+    *
+    * @return The container of kvp's needed when connecting to this institution
+    */
+  const MyMoneyKeyValueContainer& ofxConnectionSettings(void) const { return m_ofxConnectionSettings; }
+
   /**
     * This method adds the id of an account to the account list of
     * this institution It is verified, that the account is only
@@ -189,7 +209,12 @@ private:
     * available at this institution
     */
   QCStringList m_accountList;
-
+  
+  /**
+    * This member variable keeps the set of kvp's needed to establish
+    * OFX Direct Connect sessions to this institution.
+    */
+  MyMoneyKeyValueContainer m_ofxConnectionSettings;
 };
 
 #endif
