@@ -175,7 +175,7 @@ public:
     *
     * @return MyMoneyTransaction The transaction data for the instance.
     */
-  const MyMoneyTransaction transaction(void) const { return m_transaction; }
+  const MyMoneyTransaction& transaction(void) const { return m_transaction; }
 
   /**
     * Simple method that returns the schedule id.
@@ -325,7 +325,8 @@ public:
     * @param refDate the reference date from which the next payment
     *                date will be calculated (defaults to current date)
     *
-    * @return QDate The date the next payment is due. In case of an error or
+    * @return QDate The date the next payment is due. This date is
+    *         always past @a refDate.  In case of an error or
     *         if there is no more payment then an empty/invalid QDate()
     *         will be returned.
     */
