@@ -32,6 +32,7 @@
 #include <qvaluelist.h>
 #include <qdatetime.h>
 #include <kmymoney/export.h>
+#include <kmymoney/mymoneymoney.h>
 
 class QDomElement;
 class QDomDocument;
@@ -52,13 +53,13 @@ struct MyMoneyStatement
     QString m_strMemo;
     QString m_strNumber;
     QString m_strBankID;
-    double m_moneyAmount;
+    MyMoneyMoney m_amount;
 
     // the following members are only used when m_eType==etInvestment
     enum EAction { eaNone = 0, eaBuy, eaSell, eaReinvestDividend, eaCashDividend, eaEnd };
     EAction m_eAction;
-    double m_dShares;
-    double m_moneyFees;
+    MyMoneyMoney m_shares;
+    MyMoneyMoney m_fees;
     QString m_strSecurity;  // should be security ID followed by name, e.g. "DIS The Disney Corporation"
   };
 
@@ -66,7 +67,7 @@ struct MyMoneyStatement
   {
     QDate m_date;
     QString m_strSecurity;
-    double m_moneyAmount;
+    MyMoneyMoney m_amount;
   };
 
   QString m_strAccountName;
@@ -74,7 +75,7 @@ struct MyMoneyStatement
   QString m_strCurrency;
   QDate m_dateBegin;
   QDate m_dateEnd;
-  double m_moneyClosingBalance;
+  MyMoneyMoney m_closingBalance;
   EType m_eType;
 
   QValueList<Transaction> m_listTransactions;
