@@ -230,6 +230,7 @@ void MyMoneySeqAccessMgr::modifyPayee(const MyMoneyPayee& payee)
 void MyMoneySeqAccessMgr::removePayee(const MyMoneyPayee& payee)
 {
   QMap<QCString, MyMoneyTransaction>::ConstIterator it_t;
+  QMap<QCString, MyMoneySchedule>::ConstIterator it_sch;
   QValueList<MyMoneySplit>::ConstIterator it_s;
   QMap<QCString, MyMoneyPayee>::Iterator it_p;
 
@@ -244,10 +245,19 @@ void MyMoneySeqAccessMgr::removePayee(const MyMoneyPayee& payee)
     // scan all splits of this transaction
     for(it_s = (*it_t).splits().begin(); it_s != (*it_t).splits().end(); ++it_s) {
       if((*it_s).payeeId() == payee.id())
-        throw new MYMONEYEXCEPTION("Cannot remove payee that is referenced");
+        throw new MYMONEYEXCEPTION("Cannot remove payee that is referenced in a transaction");
+    }
+  }
+
+  // scan all transactions in schedules to check if the payee is still referenced
+  for(it_sch = m_scheduleList.begin(); it_sch != m_scheduleList.end(); ++it_sch) {
+    const MyMoneyTransaction& t = (*it_sch).transaction();
+    // scan all splits of this transaction
+    for(it_s = t.splits().begin(); it_s != t.splits().end(); ++it_s) {
+      if((*it_s).payeeId() == payee.id())
+        throw new MYMONEYEXCEPTION(QString("Cannot remove payee that is referenced in schedule %1").arg((*it_sch).name()));
     }
   }
-  // FIXME: check referential integrity in schedules
 
   m_payeeList.remove(it_p);
   touch();
@@ -505,13 +515,21 @@ void MyMoneySeqAccessMgr::touch(void)
 
 const bool MyMoneySeqAccessMgr::hasActiveSplits(const QCString& id) const
 {
-  QMap<QCString, MyMoneyTransaction>::ConstIterator it;
-
-  for(it = m_transactionList.begin(); it != m_transactionList.end(); ++it) {
-    if((*it).accountReferenced(id)) {
+  // check the active transactions
+  QMap<QCString, MyMoneyTransaction>::ConstIterator it_t;
+  for(it_t = m_transactionList.begin(); it_t != m_transactionList.end(); ++it_t) {
+    if((*it_t).accountReferenced(id)) {
       return true;
     }
   }
+
+  // check the scheduled transactions
+  QMap<QCString, MyMoneySchedule>::ConstIterator it_s;
+  for(it_s = m_scheduleList.begin(); it_s != m_scheduleList.end(); ++it_s) {
+    if((*it_s).transaction().accountReferenced(id))
+      return true;
+  }
+
   return false;
 }
 
