@@ -137,7 +137,7 @@ int OfxImporterPlugin::ofxTransactionCallback(struct OfxTransactionData data, vo
     if (data.invtransactiontype_valid==true)
       sign=-1.0;
 
-    t.m_moneyAmount = sign * data.amount;
+    t.m_amount = MyMoneyMoney(sign * data.amount);
   }
 
   if(data.check_number_valid==true)
@@ -195,11 +195,11 @@ int OfxImporterPlugin::ofxTransactionCallback(struct OfxTransactionData data, vo
 
   if(data.units_valid==true)
   {
-    t.m_dShares = data.units;
+    t.m_shares = MyMoneyMoney(data.units);
   }
   else
   {
-    t.m_dShares = 0;
+    t.m_shares = MyMoneyMoney();
   }
 
   bool unhandledtype = false;
@@ -309,7 +309,7 @@ int OfxImporterPlugin::ofxStatementCallback(struct OfxStatementData data, void*
 
   if(data.ledger_balance_valid==true)
   {
-    s.m_moneyClosingBalance = static_cast<double>(data.ledger_balance);
+    s.m_closingBalance = MyMoneyMoney(data.ledger_balance);
   }
 
   return 0;
