@@ -80,7 +80,7 @@ public:
   virtual void addWidget(KMyMoneyViewBase* view, QWidget* w) = 0;
 
 signals:
-  void accountSelectedForContextMenu(const MyMoneyAccount& acc);
+  void accountSelected(const MyMoneyAccount& acc);
   void viewStateChanged(bool);
 };
 
