@@ -234,8 +234,6 @@ void KAccountsView::slotListRightMouse(QListViewItem* item, const QPoint& , int
   } else {
     KAccountListItem* accountItem = static_cast<KAccountListItem*> (item);
 
-
-
     if (accountItem) {
       try {
         MyMoneyFile *file = MyMoneyFile::instance();
@@ -813,17 +811,20 @@ void KAccountsView::resizeEvent(QResizeEvent* e)
 
 void KAccountsView::slotSelectionChanged(QListViewItem *item)
 {
+  MyMoneyAccount account;
+  // notify plugins that we are about to deselect an account
+  emit accountSelected(account);
 
   KAccountListItem *accountItem = (KAccountListItem*)item;
   if (accountItem)
   {
     MyMoneyFile *file = MyMoneyFile::instance();
-
     try
     {
-      MyMoneyAccount account = file->account(accountItem->accountID());
+      account = file->account(accountItem->accountID());
       m_bSelectedAccount=true;
       m_selectedAccount = accountItem->accountID();
+      emit accountSelected(account);
       //emit accountSelected();
     }
     catch (MyMoneyException *e)
@@ -845,6 +846,18 @@ void KAccountsView::show()
   emit signalViewActivated();
 
   QWidget::show();
+
+  emit accountSelected(MyMoneyAccount());
+  try {
+    KAccountListItem* accountItem = static_cast<KAccountListItem*> (accountListView->currentItem());
+    if(accountItem) {
+      MyMoneyFile *file = MyMoneyFile::instance();
+      MyMoneyAccount account = file->account(accountItem->accountID());
+      emit accountSelected(account);
+    }
+  } catch(MyMoneyException* e) {
+    delete e;
+  }
 }
 
 void KAccountsView::slotViewSelected(QWidget* /* view */)
