@@ -43,10 +43,13 @@
 class KLedgerViewSavings : public KLedgerViewCheckings
 {
   Q_OBJECT
-public: 
+public:
   KLedgerViewSavings(QWidget *parent=0, const char *name=0);
   ~KLedgerViewSavings();
 
+  /// This has to be included for internal reasons, no API change
+  bool eventFilter(QObject* o, QEvent* e);
+
 protected slots:
   void resizeEvent(QResizeEvent*);
 
