@@ -32,8 +32,9 @@
 // Project Includes
 
 #include "kmymoneyregistercheckings.h"
-#include "../mymoney/mymoneyfile.h"
+#include "kmymoney/mymoneyfile.h"
 #include "../views/kledgerview.h"
+#include "../kmymoneyutils.h"
 
 kMyMoneyRegisterCheckings::kMyMoneyRegisterCheckings(QWidget *parent, const char *name )
   : kMyMoneyRegister(3, parent,name)
@@ -41,7 +42,7 @@ kMyMoneyRegisterCheckings::kMyMoneyRegisterCheckings(QWidget *parent, const char
   setNumCols(7);
   setCurrentCell(0, 1);
   horizontalHeader()->setClickEnabled(true);
-  horizontalHeader()->setLabel(0, i18n("Nr."));
+  horizontalHeader()->setLabel(0, i18n("No."));
   horizontalHeader()->setLabel(1, i18n("Date"));
   horizontalHeader()->setLabel(2, i18n("Payee"));
   horizontalHeader()->setLabel(3, i18n("C"));
@@ -72,10 +73,13 @@ kMyMoneyRegisterCheckings::~kMyMoneyRegisterCheckings()
 void kMyMoneyRegisterCheckings::paintCell(QPainter *p, int row, int col, const QRect& r,
                                  bool selected, const QColorGroup& cg)
 {
+  QCString splitCurrency;
+  MyMoneySplit split;
+
   setTransactionRow(row);
-  
+
   int align = Qt::AlignVCenter;
-  QString txt;
+  QString txt, addon;
   if(m_transaction != 0) {
     switch (col) {
       case 0:
@@ -95,28 +99,57 @@ void kMyMoneyRegisterCheckings::paintCell(QPainter *p, int row, int col, const Q
             break;
 
           case 1:
-            txt = m_action[m_split.action()];
+            txt = m_action[MyMoneySplit::ActionWithdrawal];
+            if(KMyMoneyUtils::transactionType(*m_transaction) == KMyMoneyUtils::Transfer) {
+              txt = m_action[MyMoneySplit::ActionTransfer];
+            } else if(KLedgerView::transactionDirection(m_split) == KLedgerView::Credit) {
+              txt = m_action[MyMoneySplit::ActionDeposit];
+            } else if( m_split.action() == MyMoneySplit::ActionCheck){
+              txt = m_action[MyMoneySplit::ActionCheck];
+            } else if(m_split.action() == MyMoneySplit::ActionATM) {
+              txt = m_action[MyMoneySplit::ActionATM];
+            }
+
             break;
         }
         break;
-        
+
       case 2:
         align |= Qt::AlignLeft;
         switch(m_transactionRow) {
           case 0:
-            try {
-              txt = MyMoneyFile::instance()->payee(m_split.payeeId()).name();
-            } catch(MyMoneyException *e) {
-              delete e;
+            if(KMyMoneyUtils::transactionType(dynamic_cast<const MyMoneyTransaction&>(*m_transaction)) == KMyMoneyUtils::InvestmentTransaction) {
+              split = KMyMoneyUtils::stockSplit(dynamic_cast<const MyMoneyTransaction&>(*m_transaction));
+              txt = MyMoneyFile::instance()->account(split.accountId()).name();
+              if(split.action() == MyMoneySplit::ActionBuyShares) {
+                if(split.value().isNegative()) {
+                  addon = i18n("Sell");
+                } else {
+                  addon = i18n("Buy");
+                }
+              } else if(split.action() == MyMoneySplit::ActionDividend) {
+                  addon = i18n("Dividend");
+              } else if(split.action() == MyMoneySplit::ActionYield) {
+                  addon = i18n("Yield");
+              }
+              if(!addon.isEmpty()) {
+                txt += QString(" (%1)").arg(addon);
+              }
+            } else {
+              try {
+                txt = MyMoneyFile::instance()->payee(m_split.payeeId()).name();
+              } catch(MyMoneyException *e) {
+                delete e;
+              }
             }
             break;
 
           case 1:
             try {
               if(m_transaction->isLoanPayment()) {
-                txt = QString(i18n("Loan payment"));
+                txt = i18n("Loan payment");
               } else if(m_transaction->splitCount() > 2)
-                txt = QString(i18n("Splitted transaction"));
+                  txt = i18n("Split transaction");
               else {
                 MyMoneySplit split = m_transaction->splitByAccount(m_split.accountId(), false);
                 txt = MyMoneyFile::instance()->accountToCategory(split.accountId());
@@ -131,7 +164,7 @@ void kMyMoneyRegisterCheckings::paintCell(QPainter *p, int row, int col, const Q
             break;
         }
         break;
-        
+
       case 3:
         switch(m_transactionRow) {
           case 0:
@@ -155,35 +188,39 @@ void kMyMoneyRegisterCheckings::paintCell(QPainter *p, int row, int col, const Q
         switch(m_transactionRow) {
           case 0:
             align |= Qt::AlignRight;
-            if(m_split.value() < 0)
-              txt = (-m_split.value()).formatMoney();
+            if(m_split.value().isNegative()) {
+              splitCurrency = MyMoneyFile::instance()->account(m_split.accountId()).currencyId();
+              txt = (-m_split.value(m_transaction->commodity(), splitCurrency)).formatMoney();
+            }
             break;
         }
         break;
-        
+
       case 5:
         switch(m_transactionRow) {
           case 0:
             align |= Qt::AlignRight;
-            if(m_split.value() >= 0)
-              txt = (m_split.value()).formatMoney();
+            if(!m_split.value().isNegative()) {
+              splitCurrency = MyMoneyFile::instance()->account(m_split.accountId()).currencyId();
+              txt = m_split.value(m_transaction->commodity(), splitCurrency).formatMoney();
+            }
             break;
         }
         break;
-        
+
       case 6:
         switch(m_transactionRow) {
           case 0:
             align |= Qt::AlignRight;
             txt = m_balance.formatMoney();
-            if(m_balance < 0)
+            if(m_balance.isNegative())
               p->setPen(QColor(255, 0, 0));
             break;
         }
         break;
     }
   }
-  
+
   // do general stuff
   kMyMoneyRegister::paintCell(p, row, col, r, selected, cg, txt, align);
 }
@@ -192,7 +229,7 @@ void kMyMoneyRegisterCheckings::adjustColumn(int col)
 {
   QHeader *topHeader = horizontalHeader();
   QFontMetrics cellFontMetrics(m_cellFont);
-  
+
   int w = topHeader->fontMetrics().width( topHeader->label( col ) ) + 10;
   if ( topHeader->iconSet( col ) )
     w += topHeader->iconSet( col )->pixmap().width();
@@ -211,7 +248,7 @@ void kMyMoneyRegisterCheckings::adjustColumn(int col)
     KMyMoneyTransaction *t = m_parent->transaction(i);
     MyMoneyMoney amount;
     int nw = 0;
-    
+
     if(t != NULL) {
       MyMoneySplit split = t->splitById(t->splitId());
       switch(col) {
@@ -222,23 +259,23 @@ void kMyMoneyRegisterCheckings::adjustColumn(int col)
           txt = t->splitById(t->splitId()).number();
           nw = cellFontMetrics.width(txt+"  ");
           break;
-        
+
         case 1:
           txt = m_action[split.action()];
           nw = cellFontMetrics.width(txt+"  ");
           break;
-        
+
         case 4:
           amount = t->splitById(t->splitId()).value();
-          if(amount < 0) {
+          if(amount.isNegative()) {
             txt = amount.formatMoney();
             nw = cellFontMetrics.width(txt+"  ");
           }
           break;
-          
+
         case 5:
           amount = t->splitById(t->splitId()).value();
-          if(amount >= 0) {
+          if(!amount.isNegative()) {
             txt = amount.formatMoney();
             nw = cellFontMetrics.width(txt+"  ");
           }
@@ -262,3 +299,5 @@ bool kMyMoneyRegisterCheckings::eventFilter(QObject* o, QEvent* e)
 {
   return kMyMoneyRegister::eventFilter(o, e);
 }
+
+#include "kmymoneyregistercheckings.moc"
